<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "Ei pystytä lataamaan listaa sovellusvarastosta (App Store)",
"Authentication error" => "Todennusvirhe",
"Unable to change display name" => "Näyttönimen muuttaminen epäonnistui",
"Group already exists" => "Ryhmä on jo olemassa",
"Unable to add group" => "Ryhmän lisäys epäonnistui",
"Could not enable app. " => "Sovelluksen käyttöönotto epäonnistui.",
"Email saved" => "Sähköposti tallennettu",
"Invalid email" => "Virheellinen sähköposti",
"Unable to delete group" => "Ryhmän poisto epäonnistui",
"Unable to delete user" => "Käyttäjän poisto epäonnistui",
"Language changed" => "Kieli on vaihdettu",
"Invalid request" => "Virheellinen pyyntö",
"Admins can't remove themself from the admin group" => "Ylläpitäjät eivät poistaa omia tunnuksiaan ylläpitäjien ryhmästä",
"Unable to add user to group %s" => "Käyttäjän tai ryhmän %s lisääminen ei onnistu",
"Unable to remove user from group %s" => "Käyttäjän poistaminen ryhmästä %s ei onnistu",
"Couldn't update app." => "Sovelluksen päivitys epäonnistui.",
"Update to {appversion}" => "Päivitä versioon {appversion}",
"Disable" => "Poista käytöstä",
"Enable" => "Käytä",
"Please wait...." => "Odota hetki...",
"Updating...." => "Päivitetään...",
"Error while updating app" => "Virhe sovellusta päivittäessä",
"Error" => "Virhe",
"Updated" => "Päivitetty",
"Saving..." => "Tallennetaan...",
"deleted" => "poistettu",
"undo" => "kumoa",
"Unable to remove user" => "Käyttäjän poistaminen ei onnistunut",
"Groups" => "Ryhmät",
"Group Admin" => "Ryhmän ylläpitäjä",
"Delete" => "Poista",
"add group" => "lisää ryhmä",
"Error creating user" => "Virhe käyttäjää luotaessa",
"__language_name__" => "_kielen_nimi_",
"Security Warning" => "Turvallisuusvaroitus",
"Your data directory and your files are probably accessible from the internet. The .htaccess file that ownCloud provides is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Data-kansio ja tiedostot ovat ehkä saavutettavissa Internetistä. .htaccess-tiedosto, jolla kontrolloidaan pääsyä, ei toimi. Suosittelemme, että muutat web-palvelimesi asetukset niin ettei data-kansio ole enää pääsyä tai siirrät data-kansion pois web-palvelimen tiedostojen juuresta.",
"Please double check the <a href='%s'>installation guides</a>." => "Lue tarkasti <a href='%s'>asennusohjeet</a>.",
"Module 'fileinfo' missing" => "Moduuli 'fileinfo' puuttuu",
"Internet connection not working" => "Internet-yhteys ei toimi",
"Cron" => "Cron",
"Sharing" => "Jakaminen",
"Enable Share API" => "Käytä jakamisen ohjelmointirajapintaa",
"Allow apps to use the Share API" => "Salli sovellusten käyttää jakamisen ohjelmointirajapintaa",
"Allow links" => "Salli linkit",
"Allow users to share items to the public with links" => "Salli käyttäjien jakaa kohteita käyttäen linkkejä",
"Allow resharing" => "Salli uudelleenjakaminen",
"Allow users to share items shared with them again" => "Mahdollistaa käyttäjien jakavan uudelleen heidän kanssaan jaettuja kohteita",
"Allow users to share with anyone" => "Salli käyttäjien jakaa kenen tahansa kanssa",
"Allow users to only share with users in their groups" => "Salli jakaminen vain samoissa ryhmissä olevien käyttäjien kesken",
"Security" => "Tietoturva",
"Enforce HTTPS" => "Pakota HTTPS",
"Enforces the clients to connect to ownCloud via an encrypted connection." => "Pakottaa salaamaan ownCloudiin kohdistuvat yhteydet.",
"Log" => "Loki",
"Log level" => "Lokitaso",
"More" => "Enemmän",
"Version" => "Versio",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Kehityksestä on vastannut <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud-yhteisö</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">lähdekoodi</a> on julkaistu lisenssin <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a> alaisena.",
"Add your App" => "Lisää sovelluksesi",
"More Apps" => "Lisää sovelluksia",
"Select an App" => "Valitse sovellus",
"See application page at apps.owncloud.com" => "Katso sovellussivu osoitteessa apps.owncloud.com",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-lisensoija <span class=\"author\"></span>",
"Update" => "Päivitä",
"User Documentation" => "Käyttäjäohjeistus",
"Administrator Documentation" => "Ylläpito-ohjeistus",
"Online Documentation" => "Verkko-ohjeistus",
"Forum" => "Keskustelupalsta",
"Bugtracker" => "Ohjelmistovirheiden jäljitys",
"Commercial Support" => "Kaupallinen tuki",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Käytössäsi on <strong>%s</strong>/<strong>%s</strong>",
"Show First Run Wizard again" => "Näytä ensimmäisen käyttökerran avustaja uudelleen",
"Password" => "Salasana",
"Your password was changed" => "Salasanasi vaihdettiin",
"Unable to change your password" => "Salasanaasi ei voitu vaihtaa",
"Current password" => "Nykyinen salasana",
"New password" => "Uusi salasana",
"Change password" => "Vaihda salasana",
"Display Name" => "Näyttönimi",
"Your display name was changed" => "Näyttönimesi muutettiin",
"Unable to change your display name" => "Näyttönimen muuttaminen epäonnistui",
"Change display name" => "Muuta näyttönimeä",
"Email" => "Sähköposti",
"Your email address" => "Sähköpostiosoitteesi",
"Fill in an email address to enable password recovery" => "Anna sähköpostiosoitteesi, jotta unohdettu salasana on mahdollista palauttaa",
"Language" => "Kieli",
"Help translate" => "Auta kääntämisessä",
"WebDAV" => "WebDAV",
"Use this address to connect to your ownCloud in your file manager" => "Käytä tätä osoitetta yhdistäessäsi ownCloudiisi tiedostonhallintaa käyttäen",
"Login Name" => "Kirjautumisnimi",
"Create" => "Luo",
"Unlimited" => "Rajoittamaton",
"Other" => "Muu",
"change display name" => "vaihda näyttönimi",
"set new password" => "aseta uusi salasana",
"Default" => "Oletus"
);
